@@ -1,7 +1,5 @@
-__version__ = "0.0.1"
-
 from .ib_protocol import IBProtocol
 from .ib_factory import IBClientFactory
 from .xmlrpc_server import XMLRPCServer
 from .exceptions import IBException
-from .applications import Solid
+from .applications import Sibi
